==> haskell-string-conversions-0.4.0.1-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-FEX4HQj6e7k5a1sJJv8Hmk
key:                  string-conversions-0.4.0.1-FEX4HQj6e7k5a1sJJv8Hmk
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  cb66e09302fb4d9cf20a48b08c9e86e7
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.0.1/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/string-conversions-0.4.0.1

hs-libraries:         HSstring-conversions-0.4.0.1-FEX4HQj6e7k5a1sJJv8Hmk
depends:
    base-4.15.0.0 bytestring-0.10.12.1 text-1.2.4.1
    utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-conversions-0.4.0.1-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-8ZoYq0HVxDcHsacv3tIOmh
key:                  string-conversions-0.4.0.1-8ZoYq0HVxDcHsacv3tIOmh
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  d7a2bc0e56ba2c8233ff16455c271520
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-8ZoYq0HVxDcHsacv3tIOmh
depends:
    base-4.15.1.0 bytestring-0.10.12.1 text-1.2.5.0
    utf8-string-1.0.2-Fg3PN5UX3ZfnukMwwaDpj

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
